@@ -1,4 +1,4 @@
-#!/usr/sbin/perl
+#!/usr/bin/perl
 #
 # by Ralph Passgang <ralph@debianbase.de> (13.11.2006 for V3.0.0)
 # by Ralph Passgang <ralph@debianbase.de> (30.06.2006 for V3.0.0)
@@ -106,6 +106,9 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
             (\$DUlastTime) voll, das Maximum heute ist \$Info{DUDailyMax}% (\$DUmaxTime)
             und das Maximum gestern war \$Info{DUDailyMaxPrev}%. (Hinweis: Sollten ca. 70% überschritten werden, so
 	    ist evtl. bald eine Erweiterung des Backupspeichers erforderlich. Ist weitere Planung nötig?)
+        <li>Das Pool Filesystem Inode (Backup-Speicherplatz) ist zu \$Info{DUInodelastValue}%
+            (\$DUlastTime) voll, das Maximum heute ist \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+            und das Maximum gestern war \$Info{DUInodeDailyMaxPrev}%.
     </ul>
 </ul>
 EOF
@@ -117,7 +120,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 <p>
 \${h2("Zur Zeit aktive Aufträge")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td> Computer </td>
     <td> Typ </td>
     <td> Benutzer </td>
@@ -136,7 +139,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 
 \${h2("Fehler, die näher analysiert werden müssen!")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Computer </td>
     <td align="center"> Typ </td>
     <td align="center"> Benutzer </td>
@@ -161,6 +164,9 @@ $Lang{BackupPC_Summary}=<<EOF;
     (\$DUlastTime) voll, das Maximum heute ist \$Info{DUDailyMax}% (\$DUmaxTime)
     und das Maximum gestern war \$Info{DUDailyMaxPrev}%. (Hinweis: Sollten ca. 70% überschritten werden, so
     ist evtl. bald eine Erweiterung des Backupspeichers erforderlich. Ist weitere Planung nötig?)
+<li>Das Pool Filesystem Inode (Backup-Speicherplatz) ist zu \$Info{DUInodelastValue}%
+    (\$DUlastTime) voll, das Maximum heute ist \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+    und das Maximum gestern war \$Info{DUInodeDailyMaxPrev}%.
 </ul>
 </p>
 
@@ -177,6 +183,7 @@ Es gibt \$hostCntGood Computer die erfolgreich gesichert wurden, mit insgesamt:
 <table class="sortable" id="host_summary_backups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Computer </td>
     <td align="center"> Benutzer </td>
+    <td align="center"> Kommentar </td>
     <td align="center"> #Voll </td>
     <td align="center"> Alter (Tage) </td>
     <td align="center"> Größe (GiB) </td>
@@ -321,6 +328,7 @@ EOF
 
 # --------------------------------
 $Lang{BackupPC__Backup_Requested_on__host} = "BackupPC: Backupauftrag für \$host";
+$Lang{BackupPC__Delete_Requested_for_a_backup_of__host} = "BackupPC: Delete Requested for a backup of \$host";
 # --------------------------------
 $Lang{REPLY_FROM_SERVER} = <<EOF;
 \${h1(\$str)}
@@ -387,8 +395,9 @@ $Lang{Backup_Queue_Summary} = <<EOF;
 <p>
 Die folgenden Benutzeraufträge sind eingereiht:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Computer </td>
+    <td> Action </td>
     <td> Uhrzeit </td>
     <td> Benutzer </td></tr>
 \$strUser
@@ -398,8 +407,9 @@ Die folgenden Benutzeraufträge sind eingereiht:
 <p>
 Die folgenden Hintergrundaufträge sind eingereiht:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Computer </td>
+    <td> Action </td>
     <td> Uhrzeit </td>
     <td> Benutzer </td></tr>
 \$strBg
@@ -408,8 +418,9 @@ Die folgenden Hintergrundaufträge sind eingereiht:
 <p>
 Die folgenden Kommandoaufträge sind eingereiht:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Computer </td>
+    <td> Action </td>
     <td> Uhrzeit </td>
     <td> Benutzer </td>
     <td> Kommando </td></tr>
@@ -438,7 +449,7 @@ $Lang{BackupPC__Log_File_History} = "BackupPC: LOG Datei Historie";
 $Lang{Log_File_History__hdr} = <<EOF;
 \${h1("LOG Datei Historie \$hdr")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Datei </td>
     <td align="center"> Größe </td>
     <td align="center"> letzte Änderung </td></tr>
@@ -450,7 +461,7 @@ EOF
 $Lang{Recent_Email_Summary} = <<EOF;
 \${h1("Übersicht der letzten E-Mails (Sortierung nach Zeitpunkt)")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Empfänger </td>
     <td align="center"> Computer </td>
     <td align="center"> Zeitpunkt </td>
@@ -656,6 +667,35 @@ $Lang{BackupPC_Archive_Reply_from_server} = <<EOF;
 Die Antwort des Server war: \$reply
 EOF
 
+
+# --------------------------------
+$Lang{BackupPC__Delete_Backup_Confirm__num_of__host} = "BackupPC: Delete Backup Confirm #\$num of \$host";
+# --------------------------------
+$Lang{A_filled} = "a filled";
+$Lang{An_unfilled} = "an unfilled";
+$Lang{Are_you_sure_delete} = <<EOF;
+\${h1("Are you sure?")}
+<p>
+You are about to delete \$filled \$type backup #\$num of \$host.
+
+<form name="Confirm" action="\$MyURL" method="get">
+
+<input type="hidden" name="host" value="\${EscHTML(\$host)}">
+<input type="hidden" name="num" value="\$num">
+
+<input type="hidden" name="doit" value="1">
+<input type="hidden" name="action" value="">
+
+Do you really want to do this?
+
+<input type="button" value="\${EscHTML(\$Lang->{CfgEdit_Button_Delete})}"
+ onClick="document.Confirm.action.value='deleteBackup';
+          document.Confirm.submit();">
+
+<input type="submit" value="No" name="ignore">
+</form>
+EOF
+
 # -------------------------
 $Lang{Host__host_Backup_Summary} = "BackupServer: Computer \$host Backupübersicht";
 
@@ -685,7 +725,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <p>
 Klicken Sie auf die Backupnummer um die Dateien zu durchsuchen und bei Bedarf wiederherzustellen.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
     <td align="center"> gefüllt </td>
@@ -693,6 +733,7 @@ Klicken Sie auf die Backupnummer um die Dateien zu durchsuchen und bei Bedarf wi
     <td align="center"> Start Zeitpunkt </td>
     <td align="center"> Dauer/min </td>
     <td align="center"> Alter/Tage </td>
+    \$deleteHdrStr
     <td align="center"> Serverbackuppfad </td>
 </tr>
 \$str
@@ -702,7 +743,7 @@ Klicken Sie auf die Backupnummer um die Dateien zu durchsuchen und bei Bedarf wi
 \$restoreStr
 </p>
 \${h2("Xfer Fehler Übersicht - bitte kontrollieren")}
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
     <td align="center"> Anzeigen </td>
@@ -720,13 +761,13 @@ Klicken Sie auf die Backupnummer um die Dateien zu durchsuchen und bei Bedarf wi
 "Neue Dateien" bedeutet neu zum Pool hinzugefügt.
 Leere Dateien und eventuelle Dateifehler sind nicht in den Summen enthalten.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Gesamt </td>
     <td align="center" colspan="2"> bestehende Dateien </td>
     <td align="center" colspan="2"> neue Dateien </td>
 </tr>
-<tr class="tableheader">
+<tr class="tableheader sortheader">
     <td align="center"> Backup# </td>
     <td align="center"> Typ </td>
     <td align="center"> #Dateien </td>
@@ -744,12 +785,12 @@ Leere Dateien und eventuelle Dateifehler sind nicht in den Summen enthalten.
 <p>
 Kompressionsergebnisse für bereits im Backup-Pool vorhandene und für neu komprimierte Dateien.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="3" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> vorhandene Dateien </td>
     <td align="center" colspan="3"> neue Dateien </td>
 </tr>
-<tr class="tableheader"><td align="center"> Backup# </td>
+<tr class="tableheader sortheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
     <td align="center"> Komp Level </td>
     <td align="center"> Größe/MB </td>
@@ -999,6 +1040,8 @@ $Lang{Only_privileged_users_can_view_log_files} = "Nur berechtigte Benutzer kön
 $Lang{Only_privileged_users_can_view_email_summaries} = "Nur berechtigte Benutzer können die E-Mail Übersicht einsehen.";
 $Lang{Only_privileged_users_can_browse_backup_files} = "Nur berechtigte Benutzer können Backup Dateien durchsuchen"
                 . " für computer \${EscHTML(\$In{host})}.";
+$Lang{Only_privileged_users_can_delete_backups} = "Only privileged users can delete backups"
+                . " of host \${EscHTML(\$host)}.";
 $Lang{Empty_host_name} = "Kein Hostname.";
 $Lang{Directory___EscHTML} = "Verzeichnis \${EscHTML(\"\$TopDir/pc/\$host/\$num\")}"
 		    . " ist leer";
@@ -1047,6 +1090,8 @@ $Lang{Backup_requested_on__host_by__User} = "Backup angefordert für \$host durc
 $Lang{Backup_stopped_dequeued_on__host_by__User} = "Backup gestoppt/gelöscht für \$host durch \$User";
 $Lang{Restore_requested_to_host__hostDest__backup___num} = "Restore beauftragt nach Computer \$hostDest, von Backup #\$num,"
 	     . " durch User \$User von Client \$ENV{REMOTE_ADDR}";
+$Lang{Delete_requested_for_backup_of__host_by__User} = "Delete requested for backup #\$num of \$host"
+             . " by \$User from \$ENV{REMOTE_ADDR}";
 $Lang{Archive_requested} = "Archivierung beauftragt durch \$User von \$ENV{REMOTE_ADDR}";
 
 # -------------------------------------------------
@@ -1185,7 +1230,7 @@ $Lang{Restore_Summary} = <<EOF;
 \${h2("Restore Übersicht")}
 <p>
 Klicken Sie auf die Restore Nummer (Restore#) für mehr Details.
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Restore# </td>
     <td align="center"> Ergebnis </td>
     <td align="right"> Start Zeitpunkt</td>
@@ -1290,7 +1335,7 @@ angeschlossen wird.
 
 Mit freundlichen Grüßen
 Ihr BackupPC Server
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # No recent backup
@@ -1321,7 +1366,7 @@ Virenbefall unbrauchbar werden.
 
 Mit freundlichen Grüßen
 Ihr BackupPC Server
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # Old Outlook files
@@ -1356,7 +1401,7 @@ Es wird folgendes Vorgehen empfohlen:
 
 Mit freundlichen Grüßen
 Ihr BackupPC Server
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 $Lang{howLong_not_been_backed_up} = "Backup nicht erfolgreich";
@@ -1375,6 +1420,7 @@ MB/sek: \$fullRate;
 #Inkr: \$incrCnt;
 Alter/Tage: \$incrAge;
 Status: \$host_state;
+Deaktiviert: \$host_disabled;
 Letzte Aktion: \$host_last_attempt;
 EOF
 
