@@ -98,6 +98,9 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
         <li>O sistema de arquivos estava recentemente em \$Info{DUlastValue}%
             (\$DUlastTime), o mximo de hoje  \$Info{DUDailyMax}% (\$DUmaxTime)
             e o mximo de ontem foi \$Info{DUDailyMaxPrev}%.
+        <li>Inode O sistema de arquivos estava recentemente em \$Info{DUInodelastValue}%
+            (\$DUlastTime), o mximo de hoje  \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+            e o mximo de ontem foi \$Info{DUInodeDailyMaxPrev}%.
     </ul>
 </ul>
 EOF
@@ -108,7 +111,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 <p>
 \${h2("Trabalhos em Execuo")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td> Host </td>
     <td> Tipo </td>
     <td> Usurio </td>
@@ -127,7 +130,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 
 \${h2("Falhas que Precisam de Ateno")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Host </td>
     <td align="center"> Tipo </td>
     <td align="center"> Usurio </td>
@@ -151,6 +154,9 @@ $Lang{BackupPC_Summary}=<<EOF;
 <li>O sistema de arquivos estava recentemente em \$Info{DUlastValue}%
     (\$DUlastTime), o m?ximo de hoje ? \$Info{DUDailyMax}% (\$DUmaxTime)
     e o m?ximo de ontem foi \$Info{DUDailyMaxPrev}%.
+<li>Inode O sistema de arquivos estava recentemente em \$Info{DUInodelastValue}%
+    (\$DUlastTime), o mximo de hoje  \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+    e o mximo de ontem foi \$Info{DUInodeDailyMaxPrev}%.
 </ul>
 </p>
 
@@ -381,8 +387,9 @@ $Lang{Backup_Queue_Summary} = <<EOF;
 <p>
 As seguintes solicitaes de usurios esto atualmente em fila:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Host </td>
+    <td> Action </td>
     <td> Hora Sol. </td>
     <td> Usurio </td></tr>
 \$strUser
@@ -392,8 +399,9 @@ As seguintes solicitaes de usurios esto atualmente em fila:
 <p>
 As seguintes solicitaes em segundo plano esto atualmente em fila:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Host </td>
+    <td> Action </td>
     <td> Hora Sol. </td>
     <td> Usurio </td></tr>
 \$strBg
@@ -402,8 +410,9 @@ As seguintes solicitaes em segundo plano esto atualmente em fila:
 <p>
 Os seguintes comandos esto atualmente em fila:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Host </td>
+    <td> Action </td>
     <td> Hora Sol. </td>
     <td> Usurio </td>
     <td> Comando </td></tr>
@@ -432,7 +441,7 @@ $Lang{BackupPC__Log_File_History} = "BackupPC: Histrico dos Logs de Registro";
 $Lang{Log_File_History__hdr} = <<EOF;
 \${h1("Histrico do Log de Registro \$hdr")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> File </td>
     <td align="center"> Tamanho </td>
     <td align="center"> Hora Modificao </td></tr>
@@ -444,7 +453,7 @@ EOF
 $Lang{Recent_Email_Summary} = <<EOF;
 \${h1("Resumo de Emails Recentes (Ordem cronolgica invertida)")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Destinatrio </td>
     <td align="center"> Host </td>
     <td align="center"> Hora </td>
@@ -708,7 +717,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <p>
 Clique no nmero do Backup para revisar e restaurar arquivos.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Cpia N </td>
     <td align="center"> Tipo </td>
     <td align="center"> Completo </td>
@@ -716,7 +725,7 @@ Clique no nmero do Backup para revisar e restaurar arquivos.
     <td align="center"> Data Incio </td>
     <td align="center"> Durao/min </td>
     <td align="center"> Idade/dias </td>
-    <td align="center"> </td>
+    \$deleteHdrStr
     <td align="center"> Rota da Cpia no Servidor </td>
 </tr>
 \$str
@@ -726,7 +735,7 @@ Clique no nmero do Backup para revisar e restaurar arquivos.
 \$restoreStr
 </p>
 \${h2("Resumo dos Erros de Transferncia")}
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Copia N </td>
     <td align="center"> Tipo </td>
     <td align="center"> Ver </td>
@@ -745,13 +754,13 @@ aqueles que sero adicionados ao lote.
 Os arquivos vazios e os erros de SMB no contam nos valores de reutilizados
 nem nos de novos.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Totais </td>
     <td align="center" colspan="2"> Arquivos Existentes </td>
     <td align="center" colspan="2"> Arquivos Novos </td>
 </tr>
-<tr class="tableheader">
+<tr class="tableheader sortheader">
     <td align="center"> Cpia N </td>
     <td align="center"> Tipo </td>
     <td align="center"> N Arquivos </td>
@@ -770,12 +779,12 @@ nem nos de novos.
 Performance de compreso para os arquivos j existentes no lote e nos
 arquivos novos comprimidos.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="3" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Arquivos Existentes </td>
     <td align="center" colspan="3"> Arquivos Novos </td>
 </tr>
-<tr class="tableheader"><td align="center"> Cpia N </td>
+<tr class="tableheader sortheader"><td align="center"> Cpia N </td>
     <td align="center"> Tipo </td>
     <td align="center"> Nvel Compr </td>
     <td align="center"> Tamanho/MB </td>
@@ -1219,7 +1228,7 @@ $Lang{Restore_Summary} = <<EOF;
 \${h2("Resumo da Restaurao")}
 <p>
 Clique no nmero da restaurao para ver seus detalhes.
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Restaurao N </td>
     <td align="center"> Resultado </td>
     <td align="right"> Data Inicio</td>
@@ -1323,7 +1332,7 @@ que estiver utilizando-o.
 
 Saudaes:
 Agente BackupPC
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # No recent backup
@@ -1354,7 +1363,7 @@ ser restaurados se seu disco danificar-se.
 
 Saudaes:
 Agente BackupPC
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # Old Outlook files
@@ -1386,7 +1395,7 @@ somente alguns minutos para completar.
 
 Saudaes:
 Agente BackupPC
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 $Lang{howLong_not_been_backed_up} = "no foi realizado nenhum backup com xito";
@@ -1405,6 +1414,7 @@ Velocidade MB/sec: \$fullRate;
 #Incrementais: \$incrCnt;
 Incrementais Antig/Dias: \$incrAge;
 Estado: \$host_state;
+Desativado: \$host_disabled;
 ltima Tentativa: \$host_last_attempt;
 EOF
 
